References
----------

.. [SEOBNRv5HM] *Laying the foundation of the effective-one-body waveform models
   SEOBNRv5: improved accuracy and efficiency for spinning non-precessing binary
   black holes*, Pompili, Buonanno, Estellés, Khalil, van de Meent, P. Mihaylov,
   Ossokine, Pürrer, Ramos-Buades, Kumar Mehta, Cotesta, Marsat, Boyle, E. Kidder,
   P. Pfeiffer, A. Scheel, R. Rüter, Vu, Dudi, Ma, Mitman, Melchor, Thomas and Sanchez,
   2023.

   Link: https://arxiv.org/abs/2303.18039

.. [SEOBNRv5HM-notes] *Note on the SEOBNRv5HM waveform model*, Pompili et al., 2023

   Link https://dcc.ligo.org/public/0186/T2300060/002/SEOBNRv5HM.pdf

.. [SEOBNRv5HM-theory] *Note on the Hamiltonian, gravitational modes and equations
   of motion of the SEOBNRv5 waveform model*, Khalil, Pompili, Buonanno et al., 2023.

   Link: https://dcc.ligo.org/public/0186/T2300060/002/SEOBNRv5_theory.pdf

.. [Buades2021] *Effective-one-body multipolar waveforms for eccentric binary black holes with
   non-precessing spins*, Ramos-Buades, Buonanno, Khalil and Ossokine, 2021.

   Link: https://arxiv.org/abs/2112.06952

.. [DCC_T2300060] SEOBNRv5 technical documents (LIGO Document T2300060-v2).

   https://dcc.ligo.org/LIGO-T2300060/public

.. [Cotesta2020] *Frequency domain reduced order model of aligned-spin effective-one-body waveforms
   with higher-order modes*, Cotesta, Marsat and Pürrer, 2020.

   Link: https://arxiv.org/abs/2003.12079

.. [Cotesta2022] *Enriching the Symphony of Gravitational Waves from Binary Black Holes
   by Tuning Higher Harmonics*, Cotesta, Buonanno, Bohé, Taracchini, Hinder and Ossokine,
   2022.

   DOI: https://doi.org/10.48550/arXiv.1803.10701

   Link: https://arxiv.org/abs/1803.10701

.. [Damour2009] *Improved resummation of post-Newtonian multipolar waveforms
   from circularized compact binaries*, Damour, Iyer and Nagar. In
   *Physical Review D79, 064004 (2009)*.

   DOI: `10.1103/PhysRevD.79.064004 <http://dx.doi.org/10.1103/PhysRevD.79.064004>`_ .

   Link: https://journals.aps.org/prd/pdf/10.1103/PhysRevD.79.064004

.. [Damour2013] *Improved effective-one-body description of coalescing nonspinning black-hole
   binaries and its numerical-relativity completion*, Damour, Nagar, Bernuzzi, 2013.

   DOI: `10.1103/PhysRevD.87.084035 <http://dx.doi.org/10.1103/PhysRevD.87.084035>`_

   Link: https://journals.aps.org/prd/pdf/10.1103/PhysRevD.87.084035

.. [Khalil2021] *Radiation-reaction force and multipolar waveforms for eccentric,
   spin-aligned binaries in the effective-one-body formalism*,
   Khalil, Buonanno, Steinhoff and Vines, in *Physical Review D104, 024046 (2021)*.

   DOI: `10.1103/PhysRevD.104.024046 <https://doi.org/10.1103/PhysRevD.104.024046>`_ .

   Link: https://journals.aps.org/prd/pdf/10.1103/PhysRevD.104.024046

.. [Berti2014] *Mixing of spherical and spheroidal modes in perturbed Kerr black holes*,
   Berti, Klein

   DOI https://doi.org/10.48550/arXiv.1408.1860 .

   Link: https://arxiv.org/abs/1408.1860

.. [Buonanno2005] *Transition from inspiral to plunge in precessing binaries of spinning black holes*,
   Buonanno, Chen, Damour

   Link: https://arxiv.org/pdf/gr-qc/0508067.pdf